using System;
using System.ComponentModel;
using System.Data;
using System.Data.OleDb;
using System.Diagnostics;
using System.Text;
using System.Xml;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Xml.Serialization;
using Microsoft.SharePoint;
using Microsoft.SharePoint.Utilities;
using Microsoft.SharePoint.WebPartPages;
using C1.Web.C1WebGrid;

namespace C1WebPartSample
{
	[ToolboxData("<{0}:C1WebGridSample runat=server></{0}:C1WebGridSample>"), XmlRoot(Namespace="C1WebPartSample")]
	public class C1WebGridSample : Microsoft.SharePoint.WebPartPages.WebPart
	{
		public enum GroupByColumns
		{
			None = 0,
			Category = 2,
			Supplier = 3,
			Country = 4,
			City = 5
		};

		private C1WebGrid grid = null;
		private const GroupByColumns defaultGrouping = GroupByColumns.None;
		private GroupByColumns grouping = defaultGrouping;
		private const bool defaultExpanded = false;
		private bool expanded = defaultExpanded;

		protected override void RenderWebPart(HtmlTextWriter output)
		{
			EnsureChildControls();
			grid.RenderControl(output);
		}

		protected override void CreateChildControls()
		{
			// create a new grid
			base.CreateChildControls();
			grid = new C1WebGrid();
			
			// add the grid to this Web Part
			this.Controls.Add(grid);
			CustomizeGrid(grid);
		}

		public virtual void CustomizeGrid(C1WebGrid grid)
		{
			if (grid.Columns.Count == 0)
				grid.LoadLayout(Page.MapPath("/webparts_data/C1WebGridSample.xml"));
			
			DataView dv = GetDataSource() as DataView;
			grid.GroupedColumns.Clear();

			if (grouping != GroupByColumns.None)
			{
				int n = System.Convert.ToInt16(grouping);
				grid.GroupedColumns.Add(grid.Columns[n]);
				C1BoundColumn bc = grid.Columns[n] as C1BoundColumn;
				bc.GroupInfo.OutlineMode = expanded ? OutlineModeEnum.StartExpanded : OutlineModeEnum.StartCollapsed;
				dv.Sort = bc.DataField;
			}
			
			grid.DataSource = dv;
			grid.DataBind();
		}

		private object GetDataSource()
		{
			string connect = "Provider=Microsoft.Jet.OLEDB.4.0;Data Source=C:\\Inetpub\\wwwroot\\webparts_data\\C1StudioLiveExamples.mdb;Persist Security Info=False";
			string command = "SELECT Products.ProductID AS ID, Products.ProductName AS Product, Categories.CategoryName AS Category, Suppliers.CompanyName AS Supplier, Suppliers.Country, Suppliers.City FROM ((Products INNER JOIN Categories ON Products.CategoryID = Categories.CategoryID) INNER JOIN Suppliers ON Products.SupplierID = Suppliers.SupplierID)";
			OleDbDataAdapter da = new OleDbDataAdapter(command, connect);
			DataSet ds = new DataSet();
			da.Fill(ds);
			DataTable dt = ds.Tables[0];
			return dt.DefaultView;
		}

		public override ToolPart[] GetToolParts()
		{
			ToolPart[] toolparts = new ToolPart[]
			{
				new CustomPropertyToolPart(),
				new WebPartToolPart()
			};

			return toolparts;
		}

		[Browsable(true),
		DefaultValue(defaultGrouping),
		WebPartStorage(Storage.Personal),
		Category("Settings"),
		FriendlyName("Group by Column"),
		Description("Select the grouping column, or None."),
		XmlElement(ElementName="GroupBy")]
		public GroupByColumns GroupBy
		{
			get { return grouping; }
			set { grouping = value; if (grid != null) CustomizeGrid(grid); }
		}

		[Browsable(true),
		DefaultValue(defaultExpanded),
		WebPartStorage(Storage.Personal),
		Category("Settings"),
		FriendlyName("Expand grouped rows"),
		Description("Check to expand all grouped rows, clear to collapse them."),
		XmlElement(ElementName="Expanded")]
		public bool Expanded
		{
			get { return expanded; }
			set { expanded = value; if (grid != null) CustomizeGrid(grid); }
		}
	}
}
